@@ -9,7 +9,7 @@
 
 #include <glibtop/sysdeps.h>
 #include <glibtop/union.h>
-#include "libgtop-i18n.h"
+#include <glib/gi18n-lib.h>
 
 #include <glibtop/command.h>
 
@@ -956,3 +956,47 @@ glibtop_get_netlist_l (glibtop *server, glibtop_netlist *buf)
 	return retval;
 }
 
+char **
+glibtop_get_proc_wd_l (glibtop *server, glibtop_proc_wd *buf,
+                       pid_t pid)
+{
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	char ** retval = (char **) 0;
+	param_buf.buf_pid = pid;
+
+	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_WD), 0);
+
+	/* If neccessary, we ask the server for the requested
+	 * feature. If not, we call the sysdeps function. */
+
+	if ((server->flags & _GLIBTOP_INIT_STATE_SERVER) &&
+	    (server->features & (1 << GLIBTOP_SYSDEPS_PROC_WD)))
+	{
+		retval = glibtop_call_l (server, GLIBTOP_CMND_PROC_WD,
+				         send_size, send_ptr,
+				         sizeof (glibtop_proc_wd), buf);
+	} else {
+#if (!GLIBTOP_SUID_PROC_WD)
+		retval = glibtop_get_proc_wd_s (server, buf, pid);
+#else
+		errno = ENOSYS;
+		glibtop_error_io_r (server, "glibtop_get_proc_wd");
+#endif
+	}
+
+	/* Make sure that all required fields are present. */
+
+	if (buf->flags & server->required.proc_wd)
+		_glibtop_missing_feature (server, "proc_wd", buf->flags,
+					  &server->required.proc_wd);
+
+	/* Now we can return. */
+
+	return retval;
+}
+
