@@ -1,5 +1,3 @@
-/* $Id: cpu.c,v 1.40 2005/12/13 09:15:49 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -48,7 +46,7 @@ static const unsigned long _glibtop_sysdeps_cpu_smp_2_6 =
 /* Init function. */
 
 void
-glibtop_init_cpu_s (glibtop *server)
+_glibtop_init_cpu_s (glibtop *server)
 {
 	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
 
