@@ -1,5 +1,3 @@
-/* $Id: swap.c,v 1.28.2.1 2005/06/13 09:09:51 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -39,7 +37,7 @@ static const unsigned long _glibtop_sysdeps_swap_paging =
 /* Init function. */
 
 void
-glibtop_init_swap_s (glibtop *server)
+_glibtop_init_swap_s (glibtop *server)
 {
 	server->sysdeps.swap = _glibtop_sysdeps_swap |
 		_glibtop_sysdeps_swap_paging;
